pub type EntryExitTransitionFn<ExtendedState, EventType, StateType, TransitionFnArguments, ErrorType> = dyn Fn(RefMut<'_, Box<ExtendedState>>, Option<StateType>, Option<EventType>) -> TransitionResult<EventType, StateType, TransitionFnArguments, ErrorType>;Expand description
transition function to either enter or exit a specific state, return same as
FSMTransitionFn. StateType passed in is previous state before currently entered or
exited state. EventType is indicating which event causes the enter or exit.
This allows to track where an FSM entered or exited a state from which can be of
high interest in “stable” states of the FSM.
In case of Entry on the first state it may be all None.